==> jc-1.4.0.tar.gz: gnu/xml/dom/DTDAttributeTypeInfo.h <==
// class gnu.xml.dom.DTDAttributeTypeInfo

// class file dependencies
// @dep_class 6b4d06017d458667 gnu_xml_dom_DTDAttributeTypeInfo
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DTDAttributeTypeInfo_H_
#define _JC_gnu_xml_dom_DTDAttributeTypeInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_refs	_jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_refs;
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_nonrefs	_jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$refs	_jc_gnu_xml_dom_DTDAttributeTypeInfo$refs;
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$nonrefs	_jc_gnu_xml_dom_DTDAttributeTypeInfo$nonrefs;
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object	_jc_gnu_xml_dom_DTDAttributeTypeInfo$object;

typedef const struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vmethods	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vmethods;
typedef const struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtable	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vtable;
typedef const struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DTDAttributeTypeInfo$method$_init$dd73ffd7332f8390(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DTDAttributeTypeInfo$method$getTypeName$271437c0e580ba86(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DTDAttributeTypeInfo$method$getTypeNamespace$33bd38b937baef29(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *);
extern jboolean _jc_gnu_xml_dom_DTDAttributeTypeInfo$method$isDerivedFrom$f18f534310af797e(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DTDAttributeTypeInfo$method_info$getTypeName$271437c0e580ba86;
extern _jc_method _jc_gnu_xml_dom_DTDAttributeTypeInfo$method_info$getTypeNamespace$33bd38b937baef29;
extern _jc_method _jc_gnu_xml_dom_DTDAttributeTypeInfo$method_info$isDerivedFrom$f18f534310af797e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vmethods {
	struct _jc_java_lang_String$object	*(*getTypeName$271437c0e580ba86)(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *);
	struct _jc_java_lang_String$object	*(*getTypeNamespace$33bd38b937baef29)(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *);
	jboolean	(*isDerivedFrom$f18f534310af797e)(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);
};

// Vtable
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vmethods	gnu_xml_dom_DTDAttributeTypeInfo;
};

// Vtype
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_refs {
	struct _jc_java_lang_String$object	*elementName;
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_lang_String$object	*mode;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$refs {
    _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_refs	gnu_xml_dom_DTDAttributeTypeInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_nonrefs	gnu_xml_dom_DTDAttributeTypeInfo;
};

// Object instance structure
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object {
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype	*vtype;
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype _jc_gnu_xml_dom_DTDAttributeTypeInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DTDAttributeTypeInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DTDAttributeTypeInfo$class_object;

#endif	/* _JC_gnu_xml_dom_DTDAttributeTypeInfo_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DTDAttributeTypeInfo.h <==
// class gnu.xml.dom.DTDAttributeTypeInfo

// class file dependencies
// @dep_class 6b4d06017d458667 gnu_xml_dom_DTDAttributeTypeInfo
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DTDAttributeTypeInfo_H_
#define _JC_gnu_xml_dom_DTDAttributeTypeInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_refs	_jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_refs;
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_nonrefs	_jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$refs	_jc_gnu_xml_dom_DTDAttributeTypeInfo$refs;
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$nonrefs	_jc_gnu_xml_dom_DTDAttributeTypeInfo$nonrefs;
typedef struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object	_jc_gnu_xml_dom_DTDAttributeTypeInfo$object;

typedef const struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vmethods	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vmethods;
typedef const struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtable	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vtable;
typedef const struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DTDAttributeTypeInfo$method$_init$dd73ffd7332f8390(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DTDAttributeTypeInfo$method$getTypeName$271437c0e580ba86(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DTDAttributeTypeInfo$method$getTypeNamespace$33bd38b937baef29(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_dom_DTDAttributeTypeInfo$method$isDerivedFrom$f18f534310af797e(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DTDAttributeTypeInfo$method_info$getTypeName$271437c0e580ba86;
extern _jc_method _jc_gnu_xml_dom_DTDAttributeTypeInfo$method_info$getTypeNamespace$33bd38b937baef29;
extern _jc_method _jc_gnu_xml_dom_DTDAttributeTypeInfo$method_info$isDerivedFrom$f18f534310af797e;

// Virtual methods structure
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vmethods {
	struct _jc_java_lang_String$object	*(*getTypeName$271437c0e580ba86)(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getTypeNamespace$33bd38b937baef29)(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *) _JC_JCNI_ATTR;
	jboolean	(*isDerivedFrom$f18f534310af797e)(_jc_env *, struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vmethods	gnu_xml_dom_DTDAttributeTypeInfo;
};

// Vtype
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_refs {
	struct _jc_java_lang_String$object	*elementName;
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_lang_String$object	*mode;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$refs {
    _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_refs	gnu_xml_dom_DTDAttributeTypeInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DTDAttributeTypeInfo$sub_nonrefs	gnu_xml_dom_DTDAttributeTypeInfo;
};

// Object instance structure
struct _jc_gnu_xml_dom_DTDAttributeTypeInfo$object {
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype	*vtype;
	_jc_gnu_xml_dom_DTDAttributeTypeInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DTDAttributeTypeInfo$vtype _jc_gnu_xml_dom_DTDAttributeTypeInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DTDAttributeTypeInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DTDAttributeTypeInfo$class_object;

#endif	/* _JC_gnu_xml_dom_DTDAttributeTypeInfo_H_ */
